@@ -50,7 +50,7 @@ def bump(ctx, filter, exclude='', image_tag=None, prefix=None, autoexclude_inact
         prev_image_tag = app.image_tag
         if image_tag is None:
             if prefix is None:
-                new_image_prefix = prev_image_tag.split('-')[0]
+                new_image_prefix = app.image_prefix
             else:
                 new_image_prefix = prefix
             new_image_tag = get_latest_image(new_image_prefix)
@@ -97,7 +97,7 @@ def command(ctx, filter, command, exclude='', cleanup=True, sequential=True, int
     else:
         # Build list of coroutines, and execute them all at once
         jobs = [(run_job(app, command, cleanup=cleanup, sequential=sequential, fargate=fargate), app.name) for app in apps]
-        asyncio.run(run_tasks_async_with_progress(jobs))
+        asyncio.run(run_tasks_async_with_progress(jobs, max_concurrency=100 if fargate else 10))
 
     print(success('Done!'))
 
@@ -245,7 +245,7 @@ def setcluster(ctx, filter, cluster, exclude=''):
         eg. inv setcluster customer,sandbox eks-prod
     """
     try:
-        apps = get_apps(filter=filter, exclude=exclude, message=f"{colourise('The following apps will be moved to the ', Fore.LIGHTBLUE_EX)} {colourise(cluster, Fore.LIGHTYELLOW_EX)} {colourise('cluster:', Fore.LIGHTBLUE_EX)}")
+        apps = get_apps(filter=filter, exclude=exclude, message=f"{colourise('The following apps will be moved to the', Fore.LIGHTBLUE_EX)} {colourise(cluster, Fore.LIGHTYELLOW_EX)} {colourise('cluster:', Fore.LIGHTBLUE_EX)}")
     except AppOperationAborted:
         print(success_negative('Aborted.'))
         return
