@@ -197,7 +197,7 @@ def render_template(template: str, values: Dict, extra_labels: Dict) -> str:
     for k, v in values.items():
         template = template.replace('{{ %s }}' % k, v)
 
-    job_json = yaml.load(template)
+    job_json = yaml.safe_load(template)
     # Adding extra labels to k8s job pod spec
     for k, v in extra_labels.items():
         job_json['spec']['template']['metadata']['labels'][k] = v
@@ -211,7 +211,6 @@ async def _run_job(path, values: Dict = None, context='', namespace='default', a
         # Generate yaml template to render
         rendered_template = render_template(open(APPS_PATH / ".." / path, 'r').read(), values, extra_labels)
         tmp.write(rendered_template)
-        print(rendered_template)
         tmp.flush()
         await async_run(f'kubectl create --context {context} -n {namespace} -f {tmp.name}')
         cmd = (
